@@ -8,7 +8,6 @@
 var events = require('events'),
     fs = require('fs'),
     path = require('path'),
-    exec = require('child_process').exec,
     spawn = require('child_process').spawn,
     async = require('async'),
     events2 = require('eventemitter2'),
@@ -16,7 +15,7 @@ var events = require('events'),
     pkgcloud = require('../../../pkgcloud');
 
 //
-// ### function Boostrapper (options)
+// ### function Bootstrapper (options)
 // #### @options {Object} Options for this instance.
 // ##### @compute {Object} Options for compute
 // ###### @provider {String} Name of the provider
@@ -212,13 +211,17 @@ Bootstrapper.prototype.createServer = function (options) {
         //
         // Grace period for IP propagation
         //
-        setTimeout(function () {
+        self._sshPoll(options, function (err) {
+          if (err) {
+            return onError(err);
+          }
+
           self.bootstrapServer(options)
             .on('error', onError)
             .on('complete', function () {
               emitter.emit('complete', server);
             });
-        }, 60 * 1000);
+        });
       }
 
       return options.afterCreate
@@ -763,3 +766,43 @@ Bootstrapper.prototype._exec = function (command, options) {
 
   return emitter;
 };
+
+//
+// ### @private function _sshPoll (options)
+// #### @options {Object} Options to use when polling the server.
+// #### @callback {function} Continuation to respond to.
+// Polls server over ssh, trying to determine when server is actually up and
+// active, ready to accept commands.
+//
+Bootstrapper.prototype._sshPoll = function (options, callback) {
+  // TODO (mmalecki): make maxTries and interval configurable
+  var self = this,
+      maxTries = 10,
+      interval = 30 * 1000,
+      tries = 0;
+
+  function poll() {
+    var child = self.ssh({
+      keys: options.keys,
+      server: options.server,
+      tunnel: options.tunnel,
+      remoteUser: options.remoteUser,
+      commands: ['true']
+    });
+
+    child.on('error', function () {
+      ++tries;
+      if (tries === maxTries) {
+        return callback(new Error('Server didn\'t become active in timely fashion'));
+      }
+
+      setTimeout(poll, interval);
+    });
+
+    child.on('complete', function () {
+      return callback();
+    });
+  }
+
+  poll();
+};
